@@ -109,7 +109,7 @@ Python usage:
 
 ```python
 from cdk_image_pipeline import ImagePipeline
-from consturcts import Construct
+from constructs import Construct
 
 # ...
 image_pipeline = ImagePipeline(
@@ -171,7 +171,7 @@ image_pipeline = ImagePipeline(
     parent_image="ami-0e1d30f2c40c4c701",
     profile_name="ImagePipelineProfile4",
     security_groups=[sg.security_group_id],
-    subnet_id=private_subnet[0].subnet_id
+    subnet_id=priv_subnets[0].subnet_id
 )
 ```
 
@@ -215,7 +215,7 @@ phases:
 ---
 
 
-[Infrastructure configuration](https://docs.aws.amazon.com/imagebuilder/latest/userguide/manage-infra-config.html) contain settings for building and testing your EC2 Image Builder image. This construct allows you to specify a list of instance types you wise to use via the `instanceTypes` property. The default is: `['t3.medium', 'm5.large', 'm5.xlarge']`.
+[Infrastructure configuration](https://docs.aws.amazon.com/imagebuilder/latest/userguide/manage-infra-config.html) contain settings for building and testing your EC2 Image Builder image. This construct allows you to specify a list of instance types you wish to use via the `instanceTypes` property. The default is: `['t3.medium', 'm5.large', 'm5.xlarge']`.
 
 ## Additional API notes
 
