@@ -12,7 +12,10 @@ import aws_cdk._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
-    "cdk-image-pipeline", "0.0.5", __name__[0:-6], "cdk-image-pipeline@0.0.5.jsii.tgz"
+    "cdk-image-pipeline",
+    "0.0.10",
+    __name__[0:-6],
+    "cdk-image-pipeline@0.0.10.jsii.tgz",
 )
 
 __all__ = [
